@@ -15,7 +15,7 @@ Usage
 
 	Customised ``.. code-block::`` directive with an adjustable indent size.
 
-	.. rst:directive:option:: tab-width:
+	.. rst:directive:option:: tab-width: width
 		:type: integer
 
 		Sets the size of the indentation in spaces.
@@ -47,19 +47,18 @@ Usage
 .. rst:directive:: .. code-cell:: [language]
 				   .. output-cell:: [language]
 
-	Customised ``.. code-block::`` directives which displays an execution count to
+	Customised ``.. code-block::`` directives which display an execution count to
 	the left of the code block, similar to a Jupyter Notebook cell.
 
-	.. rst:directive:option:: execution-count:
+	.. versionadded:: 2.6.0
+
+	.. rst:directive:option:: execution-count: count
 		:type: positive integer
 
 		The execution count of the cell.
 
-
 	All other options from the :rst:dir:`code-block` directive above are available.
 
-	.. versionadded:: 2.6.0
-
 	**Examples**
 
 	.. rest-example::
@@ -148,7 +147,7 @@ API Reference
 #
 
 # stdlib
-from typing import List
+from typing import List, MutableMapping
 
 # 3rd party
 import dict2css
@@ -230,7 +229,7 @@ class CodeCell(CodeBlock):
 	Customised code block which displays an execution count to the left of the code block,
 	similar to a Jupyter Notebook cell.
 
-	The execution count can be set using the ``:execution-count" <int>`` option.
+	The execution count can be set using the ``:execution-count: <int>`` option.
 
 	.. versionadded:: 2.6.0
 	"""  # noqa: D400
@@ -271,7 +270,7 @@ class OutputCell(CodeCell):
 	"""
 	Variant of :class:`~.CodeCell` for displaying the output of a cell in a Jupyter Notebook.
 
-	The execution count can be set using the ``:execution-count" <int>`` option.
+	The execution count can be set using the ``:execution-count: <int>`` option.
 
 	.. versionadded:: 2.6.0
 	"""
@@ -340,7 +339,7 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 	if app.builder.format.lower() != "html":
 		return
 
-	prompt_style = {
+	prompt_style: dict2css.Style = {
 			"user-select": None,
 			"font-size": "13px",
 			"font-family": '"SFMono-Regular", Menlo, Consolas, Monaco, Liberation Mono, Lucida Console, monospace',
@@ -352,7 +351,7 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 			"white-space": "nowrap",
 			}
 
-	container_style = {
+	container_style: dict2css.Style = {
 			"padding-top": "5px",
 			"display": "flex",
 			"align-items": "stretch",
@@ -360,13 +359,13 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 			}
 
 	code_style_string = "div.code-cell.container div.code-cell-code, div.output-cell.container div.output-cell-code"
-	code_style = {
+	code_style: dict2css.Style = {
 			"width": "100%",
 			"padding-top": 0,
 			"margin-top": 0,
 			}
 
-	style = {
+	style: MutableMapping[str, dict2css.Style] = {
 			"div.code-cell.container div.prompt": {"color": "#307FC1"},
 			"div.output-cell.container div.prompt": {"color": "#BF5B3D"},
 			"div.code-cell.container div.prompt, div.output-cell.container div.prompt": prompt_style,
@@ -376,7 +375,7 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 
 	static_dir = PathPlus(app.outdir) / "_static"
 	static_dir.maybe_make(parents=True)
-	(static_dir / "sphinx-toolbox-code.css").write_clean(dict2css.dumps(style))  # type: ignore
+	dict2css.dump(style, static_dir / "sphinx-toolbox-code.css")
 
 
 @metadata_add_version
@@ -386,7 +385,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 
 	.. versionadded:: 1.0.0
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	# Code block with customisable indent size.
