@@ -5,8 +5,8 @@ r"""
 .. extensions:: sphinx_toolbox.installation
 
 
-Usage
--------
+Configuration
+--------------
 
 .. confval:: conda_channels
 	:type: :class:`~typing.List`\[:class:`str`\]
@@ -14,57 +14,21 @@ Usage
 	:default: ``[]``
 
 	The conda channels required to install the library from Anaconda.
+
 	An alternative to setting it within the :rst:dir:`installation` directive.
 
 
-.. rst:directive:: extensions
-
-	Shows instructions on how to enable a Sphinx extension.
-
-	Takes a single argument -- the name of the extension.
-
-	.. rst:directive:option:: import-name
-		:type: string
-
-		The name used to import the extension, if different from the name of the extension.
-
-	.. rst:directive:option:: no-preamble
-		:type: flag
-
-		Disables the preamble text.
-
-	.. rst:directive:option:: no-postamble
-		:type: flag
-
-		Disables the postamble text.
-
-	.. rst:directive:option:: first
-		:type: flag
-
-		Puts the entry for extension before its dependencies.
-		By default is is placed at the end.
-
-		.. versionadded:: 0.4.0
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. extensions:: sphinx-toolbox
-			:import-name: sphinx_toolbox
-
-			sphinx.ext.viewcode
-			sphinx_tabs.tabs
-			sphinx-prompt
-
+Usage
+-------
 
 .. rst:directive:: installation
 
 	Adds a series of tabs providing installation instructions for the project from a number of sources.
 
-	The directive has a single required argument -- the name of the project.
-	If the project uses a different name on PyPI and/or Anaconda, the ``pypi-name`` and ``conda-name`` options can be used to set the name for those repositories.
+	The directive takes a single required argument -- the name of the project.
+	If the project uses a different name on PyPI and/or Anaconda,
+	the ``:pypi-name:`` and ``:conda-name:`` options can be used to set the name
+	for those repositories.
 
 	.. rst:directive:option:: pypi
 		:type: flag
@@ -125,6 +89,48 @@ Usage
 			:github:
 
 
+.. rst:directive:: extensions
+
+	Shows instructions on how to enable a Sphinx extension.
+
+	The directive takes a single argument -- the name of the extension.
+
+	.. rst:directive:option:: import-name
+		:type: string
+
+		The name used to import the extension, if different from the name of the extension.
+
+	.. rst:directive:option:: no-preamble
+		:type: flag
+
+		Disables the preamble text.
+
+	.. rst:directive:option:: no-postamble
+		:type: flag
+
+		Disables the postamble text.
+
+	.. rst:directive:option:: first
+		:type: flag
+
+		Puts the entry for extension before its dependencies.
+		By default is is placed at the end.
+
+		.. versionadded:: 0.4.0
+
+
+	**Example**
+
+	.. rest-example::
+
+		.. extensions:: sphinx-toolbox
+			:import-name: sphinx_toolbox
+
+			sphinx.ext.viewcode
+			sphinx_tabs.tabs
+			sphinx-prompt
+
+
 API Reference
 --------------
 """  # noqa: D400
@@ -170,6 +176,7 @@ from sphinx.environment import BuildEnvironment
 from sphinx.util.docutils import SphinxDirective
 
 # this package
+from sphinx_toolbox import _css
 from sphinx_toolbox.utils import OptionSpec, Purger, SphinxExtMetadata, flag, metadata_add_version
 
 __all__ = [
@@ -194,7 +201,7 @@ class _Purger(Purger):
 		"""
 		Remove all redundant nodes.
 
-		:param app: The Sphinx app.
+		:param app: The Sphinx application.
 		:param env: The Sphinx build environment.
 		:param docname: The name of the document to remove nodes for.
 		"""
@@ -574,10 +581,12 @@ class ExtensionsDirective(SphinxDirective):
 		targetid = f'extensions-{self.env.new_serialno("sphinx-toolbox extensions"):d}'
 		targetnode = nodes.target('', '', ids=[targetid])
 
-		top_text = (
-				f"Enable ``{self.arguments[0]}`` by adding the following "
-				f"to the ``extensions`` variable in your ``conf.py``:"
-				)
+		top_text = [
+				".. rst-class:: sphinx-toolbox-extensions",
+				'',
+				f"    Enable ``{self.arguments[0]}`` by adding the following",
+				f"    to the ``extensions`` variable in your ``conf.py``:",
+				]
 		bottom_text = (
 				"For more information see "
 				"https://www.sphinx-doc.org/en/master/usage/extensions#third-party-extensions ."
@@ -586,10 +595,14 @@ class ExtensionsDirective(SphinxDirective):
 		if "no-preamble" in self.options:
 			content = []
 		else:
-			content = [top_text, '']
+			content = [*top_text, '']
+
+		content.append(".. code-block:: python", )
+
+		if "no-postamble" not in self.options:
+			content.append("    :class: sphinx-toolbox-extensions")
 
 		content.extend([
-				".. code-block:: python",
 				'',
 				"    extensions = [",
 				"        ...",
@@ -614,23 +627,22 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 	"""
 	Copy additional stylesheets into the HTML build directory.
 
+	.. versionadded:: 1.2.0
+
 	:param app: The Sphinx application.
 	:param exception: Any exception which occurred and caused Sphinx to abort.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	if exception:  # pragma: no cover
 		return
 
-	style: MutableMapping[str, dict2css.Style] = {
-			'div[id*="installation"] .sphinx-tabs-tab': {"color": "#2980b9"},
-			"button.sphinx-tabs-tab,div.sphinx-tabs-panel": {"outline": (None, dict2css.IMPORTANT)},
-			}
+	if app.builder.format.lower() != "html":
+		return
 
 	static_dir = PathPlus(app.outdir) / "_static"
 	static_dir.maybe_make(parents=True)
-	(static_dir / "sphinx_toolbox_installation.css").write_clean(dict2css.dumps(style, minify=True))
+	dict2css.dump(_css.installation_styles, static_dir / "sphinx_toolbox_installation.css", minify=True)
+
 	(static_dir / "sphinx_toolbox_installation.js").write_lines([
 			"// Based on https://github.com/executablebooks/sphinx-tabs/blob/master/sphinx_tabs/static/tabs.js",
 			"// Copyright (c) 2017 djungelorm",
@@ -680,13 +692,14 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 
 	.. versionadded:: 0.7.0
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	if "sphinx_inline_tabs" not in getattr(app, "extensions", ()):
 		app.setup_extension("sphinx_tabs.tabs")
 
 	app.setup_extension("sphinx-prompt")
+	app.setup_extension("sphinx_toolbox._css")
 
 	app.add_config_value("conda_channels", [], "env", types=[list])
 
